## get the data set
source("get_data.R")
source("runNN.R")
source("runXgboost.R")

## load xgboost
library(xgboost)
library(keras)

## scaling function that we need later on
scalef <- function(x) (x-min(x)) / (max(x)-min(x))


## evaluate the xgboost model
rmse_gb <- NULL
for(seed in 1:10){
  print(seed)
  res <- runXgboost(seed=seed,eval="test")
  rmse_gb <- c(rmse_gb,res)
}


## evaluate the NN model
rmse_nn <- NULL
for(seed in 1:10){
  print(seed)
  res <- runNN(seed=seed,eval="test")
  rmse_nn <- c(rmse_nn,res)
}

## boxplot of result
boxplot(rmse_gb,rmse_nn,horizontal = TRUE, names = c("GB", "NN"),xlab="rmse")

## load results of the scripts "tuneNN.R" and "tuneXgboost.R" 
load("resultFileNN.RData")
rmse_nn_tuned <- best
load("resultFilexgboost.RData")
rmse_gb_tuned <- best

## boxplot of all results, including after tuning
boxplot(rmse_gb,rmse_gb_tuned,rmse_nn,rmse_nn_tuned,horizontal = TRUE, names = c("GB","GB*","NN","NN*"),xlab="rmse")

## save for later use
save(rmse_gb,rmse_gb_tuned,rmse_nn,rmse_nn_tuned,file="rmses.RData")
