
## read the data file:
data <- read.table("auto-mpg.data",na.strings = "?")

## rename to readable column names / feature names
names(data) <- c("mpg","cylinders","displacement",
                 "horsepower","weight","acceleration",
                 "model_year","origin","car_name")

## remove the car_name column
data$car_name <- NULL 

## remove NA values
data <- data[!is.na(data$horsepower),]

## set seed for data split
set.seed(0)

## split data into train & validation vs. test
split_data <- sample(c("trainval","test"), 
                     nrow(data),
                     prob=c(0.85,0.15),
                     replace=T)

## also convert to matrix (xgboost implementation requirement)
trainval_data <- as.matrix(data[split_data=="trainval",-1])
trainval_label <- data[split_data=="trainval",1]
test_data <- as.matrix(data[split_data=="test",-1])
test_label <- data[split_data=="test",1]

get_train_val_data <- function(seed,data,data_label){
  set.seed(seed)
  
  ## split data into train vs.validation 
  split_data <- sample(c("train","val"), 
                       nrow(data),
                       prob=c(0.85,0.15),
                       replace=T)
  
  ## also convert to matrix (xgboost implementation requirement)
  train_data <- data[split_data=="train",]
  train_label <- data_label[split_data=="train"]
  val_data <- data[split_data=="val",]
  val_label <- data_label[split_data=="val"]
  return(list(train_data=train_data,train_label=train_label,val_data=val_data,val_label=val_label))
}