runNN <- function(epochs=100,batch_size=32,units=20,lr=0.001,activation="linear",seed,eval="train"){
  ## get the data set
  source("get_data.R")
  
  library(keras)
  
  ## scaling function that we need later on
  scalef <- function(x) (x-min(x)) / (max(x)-min(x))
  
  ## set random seed for modeling
  set.seed(seed)
  dat <- get_train_val_data(seed,trainval_data,trainval_label)
  if(eval=="test"){
    dat$val_data <- test_data
    dat$val_label <- test_label
  }
  tensorflow::set_random_seed(seed)
  
  model <- keras_model_sequential()
  
  ## Add layers to the model
  model %>% 
    layer_dense(units = units, activation = activation, input_shape = ncol(dat$train_data)) %>% 
    layer_dense(units = 1, activation="linear")
  
  ## Compile the model
  model %>% compile(loss = 'mse',
                    optimizer = optimizer_adam(lr = lr))
  
  ## Fit the model
  histo <- model %>% fit(x=apply(dat$train_data,2,scalef), 
                         y=dat$train_label, 
                         verbose=0,
                         epochs = epochs, batch_size = batch_size)
  
  rmse_val_nn <- sqrt(model %>% evaluate(apply(dat$val_data,2,scalef), 
                                         dat$val_label, verbose=0))
  
  return(rmse_val_nn)
}